# -*- coding: cp1252 -*-
#------------------------------------------------------------------------------
# Name:        01_Analyse_SIG.py
# Version:     1.0
#
# Purpose:     Strategische Revitalisierungsplanung Seeufer: GIS-Analyse
#
# Author:      Sigmaplan AG, Bern
#
# Last Edited: 15.02.2019
#
# Copyright:   (c) BAFU
#
# Python:      2.7.5
# ArcGIS:      10.4.1 (ArcView License)
#------------------------------------------------------------------------------

import os
import arcpy
import datetime

starttime = datetime.datetime.now()

## *********************************************************************************************************
# Benutzereingaben und Umgebung
in_oekmo_attr = arcpy.GetParameterAsText(0) + "\\"
in_oekmo_ziel = arcpy.GetParameterAsText(1) + "\\"
in_BAUS = arcpy.GetParameterAsText(2) + "\\"
in_BAUS_Attr = arcpy.GetParameterAsText(3)
in_BAFWZ = arcpy.GetParameterAsText(4) + "\\"
in_BAFWZ_Attr = arcpy.GetParameterAsText(5)
in_OEB = arcpy.GetParameterAsText(6) + "\\"
in_OEB_Attr = arcpy.GetParameterAsText(7)
in_Uferlinie = arcpy.GetParameterAsText(8) + "\\"
in_Uferlinie_Attr = arcpy.GetParameterAsText(9)
out_gdb = arcpy.GetParameterAsText(10) + "\\"
path_script = os.path.dirname(sys.argv[0])
path_in = path_script.replace("\\", r"\\")
arcpy.env.workspace = out_gdb
arcpy.env.overwriteOutput = True
event_prop = "ID_Uferlinie LINE Von Bis"


## *********************************************************************************************************
# Weitere Variablen und Listen

# Listen Attribute
zielerreichung = ["KeineNutzung_US", "NN_Uferstreifen", "NN_Hinterlandstr", "NN_Uferzone",
                  "NN_Uferlinie", "NN_FlachWZ", "NN_Oekomorphologie"]
allg_Attribute = ['OBJECTID', 'ID_Uferlinie', 'Von', 'Bis']
Attribute = ['RBUS', 'RBFWZ', 'RBUL', 'RBHL', 'RB',
             'BAUS', 'BAFWZ', 'UTUS', 'UTFWZ',
             'ULWUS', 'ULWFWZ', 'HLW','APUS', 'APFWZ',
             'APP', 'AP', 'OEB', 'GISNP', 'GISN',
             'offset_a1', 'offset_a2', 'offset_i1', 'offset_i2']
list_attr_BAFWZ = ["OBJECTID", "ID_Uferlinie", "Von", "Bis", "E01", "E02", "E03", "BAFWZ_opt"]
list_attr_BAUS = ["OBJECTID", "ID_Uferlinie", "Von", "Bis", "C01", "C02", "C03", "C04", "C05", "C07", "BAUS_opt"]
# unterteilt wegen Reihenfolge in Tabelle REVIT
Attribute_short1 = ['RBUS', 'RBFWZ', 'RBUL', 'RBHL', 'RB']
Attribute_float1 = ['BAUS', 'BAFWZ', 'UTUS', 'UTFWZ']
Attribute_short2 = ['ULWUS', 'ULWFWZ', 'HLW','APUS', 'APFWZ',
                    'APP', 'AP']
Attribute_float2 = ['OEB']
Attribute_short3 = ['GISNP', 'GISN',
                    'offset_a1', 'offset_a2', 'offset_i1', 'offset_i2']

# Namen Oekomorphologieebenen
table_C01 = "C01"
table_C02 = "C02"
table_C03 = "C03"
table_C04 = "C04"
table_C05 = "C05"
table_C07 = "C07"
table_E01 = "E01"
table_E02 = "E02"
table_E03 = "E03"

# Punkte fuer Verlegungsaufwand Uferstreifen (gross=0.5; mittel=1; klein=2; kein=0)
# C07 Faktoren fuer Steilheit Uferstreifen (0.5 / 1 / 1.5)
code_US = {
        "C01.01":0, "C01.02":2, "C01.03":1, "C01.0301":0.5, "C01.0302":2, "C01.0303":1, "C01.04":2,
        "C01.05":0.5, "C01.0501":0.5, "C01.0502":0.5, "C01.0503":0.5, "C01.0504":0.5,
        "C01.06":0.5, "C01.0601":0.5, "C01.0602":0.5, "C01.0603":0.5, "C01.0604":0.5, "C01.0605":0.5,
        "C01.07":0.5, "C01.0701":0.5, "C01.0702":0.5, "C01.0703":0.5, "C01.0704":0.5,
        "C02.01":0, "C02.02":0, "C02.03":2, "C02.0301":2, "C02.0302":2, "C02.0303":2,
        "C02.0304":2, "C02.0305":2, "C02.0306":2, "C02.04":0.5, "C02.0401":0.5, "C02.0402":0.5,
        "C02.0403":0.5, "C02.0404":0.5, "C02.0405":0.5, "C02.0406":0.5, "C02.05":0.5, "C02.0501":0.5,
        "C03.01":0, "C03.02":2, "C03.03":2, "C03.04":2, "C03.05":2, "C03.06":1,
        "C03.07":1, "C03.08":0.5, "C03.09":0.5, "C03.10":0.5, "C03.11":0.5,
        "C04.01":0, "C04.02":0, "C04.0201":0, "C04.0202":0, "C04.0203":0, "C04.0204":0,
        "C04.03":0, "C04.0301":1, "C04.0302":2, "C04.0303":0, "C04.0304":2, "C04.04":0,
        "C05.01":0, "C05.02":0, "C05.03":2, "C05.04":2, "C05.05":1, "C05.06":0.5, "C05.07":2,
        "C07.01":0.5, "C07.02":0.5, "C07.03":1, "C07.04":1.5, "C07.05":1.5,
        }

# Punkte fuer Verlegungsaufwand Flachwasserzone (gross=0.5; mittel=1; klein=2; kein=0)
# E03 Punkte fuer Ausdehnung/Steilheit Flachwasserzone (0.5 / 1 / 1.5)
code_FW = {
        "E01.01":0, "E01.02":0, "E01.0201":0, "E01.03":0, "E01.04":0, "E01.05":0, "E01.06":0,
        "E01.0601":0, "E01.0602":0, "E01.0603":0,  "E01.07":1, "E01.08":1,
        "E02.01":0, "E02.02":2, "E02.0201":2, "E02.0202":0, "E02.0203":0.5, "E02.0204":0,
        "E02.03":1, "E02.0301":0.5, "E02.0302":2, "E02.0303":2, "E02.0304":0.5, "E02.0305":1,
        "E02.04":0.5, "E02.0401":2, "E02.0402":2, "E02.0403":1, "E02.0404":0.5, "E02.0405":0.5,
        "E02.0406":2, "E02.0407":2, "E02.0408":1, "E02.0409":0.5, "E02.0410":2, "E02.0411":1,
        "E02.0412":1, "E02.0413":1,
        "E02.05":0.5, "E02.0501":0.5, "E02.0502":0.5, "E02.0503":0.5, "E02.0504":0.5, "E02.0505":0.5,
        "E03.01":0.5, "E03.02":1, "E03.03":1.5, "E03.04":1.5, "E03.05":1.5,
        }

# Standardwerte Offset
offset_a1 = 5
offset_a2 = 10
offset_i1 = -5
offset_i2 = -10

# Domains
values_JaNein = {(0,"non"), (1,"oui")}
values_RB = {(0,"naturel, proche de ltat naturel"), (2,"peu dgrad"), (4,"dgrad"), (6,"non naturel"), (8,"artificiel"), (-1,"indtermin")} # Revitalisierungsbedarf
values_BA = {("0.5","important"), ("1","moyen"), ("2","faible"), ("0","nul")} # baulicher Aufwand
values_AP = {(1,"faible"),(2,"moyen"), (3,"important")} # Aufwertungspotenzial
values_Nutzen = {(1,"faible/nul"), (2,"moyen"), (3,"important")}
values_Frist= {(1,"jusqu'en 2024"), (2,"2025-28"), (3,"2029-32"), (4,"2033-36"), (5,"2037-40"), (6,"2041 ou ultrieurement")}

list_domain = [
    ("domJaNein", "oui / non", "SHORT", "CODED", values_JaNein),
    ("domRB", "Besoin de revitalisation", "SHORT", "CODED", values_RB),
    ("domBA", "Effort d'amnagement", "FLOAT", "CODED", values_BA),
    ("domAP", "Potentiel de valorisation", "SHORT", "CODED", values_AP),
    ("domNutzen", "Bnfice", "SHORT", "CODED",  values_Nutzen),
    ("domFrist", "Dlais", "SHORT", "CODED", values_Frist)
    ]

attribute_domain = [
    ("REVIT", "RBUS", "domRB"),
    ("REVIT", "RBFWZ", "domRB"),
    ("REVIT", "RBUL", "domRB"),
    ("REVIT", "RBHL", "domRB"),
    ("REVIT", "RB", "domRB"),
    ("REVIT", "BAUS", "domBA"),
    ("REVIT", "BAFWZ", "domBA"),
    ("REVIT", "AP", "domAP"),
    ("REVIT", "GISN", "domNutzen")
    ]


## *********************************************************************************************************
# Funktionen

def msgOut(msg):
    print msg
    arcpy.AddMessage(msg)

def errOut(err):
    print err
    print arcpy.GetMessages()
    print datetime.datetime.now()-starttime
    arcpy.AddError(err)
    arcpy.AddError(arcpy.GetMessages())
    arcpy.AddError(datetime.datetime.now()-starttime)

def oekmo(nn_oekmo):
    """ Wandelt die stetigen Oekomorphologiewerte in 0, 2, 4, 6, oder 8 um.
    """
    try:
        if nn_oekmo >= 0.8:
            if nn_oekmo <= 1:
                nn_oekmo = 0
            else:
                nn_oekmo = -1
        elif nn_oekmo >= 0.6:
            nn_oekmo = 2
        elif nn_oekmo >= 0.4:
            nn_oekmo = 4
        elif nn_oekmo >= 0.2:
            nn_oekmo = 6
        elif nn_oekmo >= 0:
            nn_oekmo = 8
        else:
            nn_oekmo = -1
        return nn_oekmo
    except:
        print "ERREUR : erreur lors du calcul du besoin de revitalisation."
        print "Dure: ", datetime.datetime.now()-starttime


## *********************************************************************************************************
#  Schritt 1a: Oekomorphologie
try:
    msgOut(u"\nCopie des tables...")
    arcpy.TableToTable_conversion(in_oekmo_ziel, out_gdb, "REVIT")
    arcpy.TableToTable_conversion(in_oekmo_ziel, out_gdb, "OEKMO") # fuer Export MGDM
    arcpy.TableToTable_conversion(in_OEB, out_gdb, "loc_OEB")
    arcpy.AlterField_management(out_gdb + "loc_OEB", str(in_OEB_Attr), "temp_OEB")
    arcpy.FeatureClassToFeatureClass_conversion(in_Uferlinie, out_gdb, "Uferlinie")
    arcpy.AlterField_management(out_gdb + "Uferlinie", str(in_Uferlinie_Attr), "ID_Uferlinie")
    # optionale Daten
    if len(in_BAUS) > 1:
        arcpy.TableToTable_conversion(in_BAUS, out_gdb, "loc_BAUS_opt")
        if len(in_BAUS_Attr) < 1:
            msgOut(u"\nAttribut concern (bande riveraine).")
            sys.exit(1)
        else:
            arcpy.AlterField_management(out_gdb + "loc_BAUS_opt", str(in_BAUS_Attr), "BAUS_opt")

    if len(in_BAFWZ) > 1:
        arcpy.TableToTable_conversion(in_BAFWZ, out_gdb, "loc_BAFWZ_opt")
        if len(in_BAFWZ_Attr) < 1:
            msgOut(u"\nAttribut concern (zone littorale).")
            sys.exit(1)
        else:
            arcpy.AlterField_management(out_gdb + "loc_BAFWZ_opt", str(in_BAFWZ_Attr), "BAFWZ_opt")

    msgOut(u"\nAjout des attributs...")
    for Attribut in Attribute_short1:
        arcpy.AddField_management(out_gdb + "REVIT", Attribut, "SHORT")
    for Attribut in Attribute_float1:
        arcpy.AddField_management(out_gdb + "REVIT", Attribut, "FLOAT")
    for Attribut in Attribute_short2:
        arcpy.AddField_management(out_gdb + "REVIT", Attribut, "SHORT")
    for Attribut in Attribute_float2:
        arcpy.AddField_management(out_gdb + "REVIT", Attribut, "FLOAT")
    for Attribut in Attribute_short3:
        arcpy.AddField_management(out_gdb + "REVIT", Attribut, "SHORT")

    msgOut(u"\nCalcul du besoin de revitalisation...")
    with arcpy.da.UpdateCursor(out_gdb + "REVIT", ["RBUS", "NN_Uferstreifen", "RBFWZ", "NN_FlachWZ",
                                                   "RBUL", "NN_Uferlinie", "RBHL", "NN_Hinterlandstr", "RB", "NN_Oekomorphologie"]) as rows:
        for row in rows:
            row[0] = oekmo(row[1])
            row[2] = oekmo(row[3])
            row[4] = oekmo(row[5])
            row[6] = oekmo(row[7])
            row[8] = oekmo(row[9])
            rows.updateRow(row)

except:
    errOut(u"\nERREUR: erreur lors du calcul des rsultats intermdiaires de lcomorphologie.")
    sys.exit(1)

## *********************************************************************************************************
#  Schritt 1b: Baulicher Aufwand und Topografie Uferstreifen
try:
    msgOut(u"\nDtermination de leffort damnagement et de la topographie de la bande riveraine...")
    fields = ["C01", "C02", "C03", "C04", "C05", "C07"]
    arcpy.TableSelect_analysis(in_oekmo_attr + table_C01, out_gdb + "loc_C01")
    arcpy.AlterField_management(out_gdb + "loc_C01", "Code", "C01", "C01")
    arcpy.TableSelect_analysis(in_oekmo_attr + table_C02, out_gdb + "loc_C02")
    arcpy.AlterField_management(out_gdb + "loc_C02", "Code", "C02", "C02")
    arcpy.TableSelect_analysis(in_oekmo_attr + table_C03, out_gdb + "loc_C03")
    arcpy.AlterField_management(out_gdb + "loc_C03", "Code", "C03", "C03")
    arcpy.TableSelect_analysis(in_oekmo_attr + table_C04, out_gdb + "loc_C04")
    arcpy.AlterField_management(out_gdb + "loc_C04", "Code", "C04", "C04")
    arcpy.TableSelect_analysis(in_oekmo_attr + table_C05, out_gdb + "loc_C05")
    arcpy.AlterField_management(out_gdb + "loc_C05", "Code", "C05", "C05")
    arcpy.TableSelect_analysis(in_oekmo_attr + table_C07, out_gdb + "loc_C07")
    arcpy.AlterField_management(out_gdb + "loc_C07", "Code", "C07", "C07")

    arcpy.OverlayRouteEvents_lr(out_gdb + "loc_C01", event_prop, out_gdb + "loc_C02", event_prop, "UNION", out_gdb + "loc_BAUS_2_Layer", event_prop, "NO_ZERO")
    arcpy.OverlayRouteEvents_lr(out_gdb + "loc_BAUS_2_Layer", event_prop, out_gdb + "loc_C03", event_prop, "UNION", out_gdb + "loc_BAUS_3_Layer", event_prop, "NO_ZERO")
    arcpy.OverlayRouteEvents_lr(out_gdb + "loc_BAUS_3_Layer", event_prop, out_gdb + "loc_C04", event_prop, "UNION", out_gdb + "loc_BAUS_4_Layer", event_prop, "NO_ZERO")
    arcpy.OverlayRouteEvents_lr(out_gdb + "loc_BAUS_4_Layer", event_prop, out_gdb + "loc_C05", event_prop, "UNION", out_gdb + "loc_BAUS_5_Layer", event_prop, "NO_ZERO")
    arcpy.OverlayRouteEvents_lr(out_gdb + "loc_BAUS_5_Layer", event_prop, out_gdb + "loc_C07", event_prop, "UNION", out_gdb + "loc_BAUS_detail", event_prop, "NO_ZERO")

    for field in fields:
        with arcpy.da.UpdateCursor(out_gdb + "loc_BAUS_detail", field) as rows:
            for row in rows:
                if row[0] == None or row[0] == '':
                    row[0] = 0
                    rows.updateRow(row)
                elif row[0] in code_US:
                    x = row[0]
                    row[0] = code_US.get(x) # Umweg via Variable notwendig
                    rows.updateRow(row)
                else:
                    row[0] = 0
                    rows.updateRow(row)

    with arcpy.da.UpdateCursor(out_gdb + "loc_BAUS_detail", ["C07"]) as rows:
        for row in rows:
            if row[0] == "":
                row[0] = 0
            rows.updateRow(row)

    Codes = [a.name for a in arcpy.ListFields(out_gdb + "loc_BAUS_detail")]
    for attr in Codes:
        if attr not in list_attr_BAUS:
            arcpy.DeleteField_management(out_gdb + "loc_BAUS_detail", str(attr))

    # optionale Daten angegeben
    if arcpy.Exists(out_gdb + "loc_BAUS_opt"):
        arcpy.OverlayRouteEvents_lr(out_gdb + "loc_BAUS_detail", event_prop, out_gdb + "loc_BAUS_opt", event_prop, "UNION", out_gdb + "loc_BAUS_detail_opt", event_prop, "NO_ZERO")

        Codes = [a.name for a in arcpy.ListFields(out_gdb + "loc_BAUS_detail_opt")]
        for attr in Codes:
            if attr not in list_attr_BAUS:
                arcpy.DeleteField_management(out_gdb + "loc_BAUS_detail_opt", str(attr))

    if arcpy.Exists(out_gdb + "loc_BAUS_opt"):
        arcpy.AddField_management(out_gdb + "loc_BAUS_detail_opt", "temp_BAUS", "FLOAT")

        with arcpy.da.UpdateCursor(out_gdb + "loc_BAUS_detail_opt", ["C01", "C02", "C03", "C04", "C05", "BAUS_opt", "temp_BAUS"]) as rows:
            for row in rows:
                a = str(row[0])
                b = str(row[1])
                c = str(row[2])
                d = str(row[3])
                e = str(row[4])
                f = str(row[5])

                if a == '0' and b == '0' and c == '0' and d == '0' and e == '0' and f == '0':
                    row[6] = 0
                elif a == '0.5' or b == '0.5' or c == '0.5' or d == '0.5' or e == '0.5' or f == '0.5':
                    row[6] = 0.5
                elif a == '0,5' or b == '0,5' or c == '0,5' or d == '0,5' or e == '0,5' or f == '0,5':  # bei Verwendung von Komma in regionalen Einstellungen
                    row[6] = 0.5
                elif a == '1' or b == '1' or c == '1' or d == '1' or e == '1' or f == '1':
                    row[6] = 1
                elif a == '2' or b == '2' or c == '2' or d == '2' or e == '2' or f == '2':
                    row[6] = 2
                else:
                    row[6] = 0

                rows.updateRow(row)

        arcpy.DissolveRouteEvents_lr(out_gdb + "loc_BAUS_detail_opt", event_prop, ["temp_BAUS"], out_gdb + "loc_BAUS", event_prop, "CONCATENATE")

    else:
        arcpy.AddField_management(out_gdb + "loc_BAUS_detail", "temp_BAUS", "FLOAT")

        with arcpy.da.UpdateCursor(out_gdb + "loc_BAUS_detail", ["C01", "C02", "C03", "C04", "C05", "temp_BAUS"]) as rows:
            for row in rows:
                a = str(row[0])
                b = str(row[1])
                c = str(row[2])
                d = str(row[3])
                e = str(row[4])

                if a == '0' and b == '0' and c == '0' and d == '0' and e == '0':
                    row[5] = 0
                elif a == '0.5' or b == '0.5' or c == '0.5' or d == '0.5' or e == '0.5':
                    row[5] = 0.5
                elif a == '0,5' or b == '0,5' or c == '0,5' or d == '0,5' or e == '0,5':  # bei Verwendung von Komma in regionalen Einstellungen
                    row[5] = 0.5
                elif a == '1' or b == '1' or c == '1' or d == '1' or e == '1':
                    row[5] = 1
                elif a == '2' or b == '2' or c == '2' or d == '2' or e == '2':
                    row[5] = 2
                else:
                    row[5] = 0

                rows.updateRow(row)

        arcpy.DissolveRouteEvents_lr(out_gdb + "loc_BAUS_detail", event_prop, ["temp_BAUS"], out_gdb + "loc_BAUS", event_prop, "CONCATENATE")

    arcpy.DissolveRouteEvents_lr(out_gdb + "loc_BAUS_detail", event_prop, ["C07"], out_gdb + "loc_UTUS", event_prop, "CONCATENATE")
    arcpy.AlterField_management(out_gdb + "loc_UTUS", "C07", "temp_UTUS", "temp_UTUS")

except:
    errOut(u"\nERREUR: erreur lors du calcul de leffort damnagement et de la topographie de la bande riveraine.")
    sys.exit(1)

## *********************************************************************************************************
#  Schritt 1c: Baulicher Aufwand und Topografie Flachwasserzone
try:
    msgOut(u"\nDtermination de leffort damnagement et de la topographie de la zone littorale...")
    fields = ["E01", "E02", "E03"]
    arcpy.TableSelect_analysis(in_oekmo_attr + table_E01, out_gdb + "loc_E01")
    arcpy.AlterField_management(out_gdb + "loc_E01", "Code", "E01", "E01")
    arcpy.TableSelect_analysis(in_oekmo_attr + table_E02, out_gdb + "loc_E02")
    arcpy.AlterField_management(out_gdb + "loc_E02", "Code", "E02", "E02")
    arcpy.TableSelect_analysis(in_oekmo_attr + table_E03, out_gdb + "loc_E03")
    arcpy.AlterField_management(out_gdb + "loc_E03", "Code", "E03", "E03")

    arcpy.OverlayRouteEvents_lr(out_gdb + "loc_E01", event_prop, out_gdb + "loc_E02", event_prop, "UNION", out_gdb + "loc_BAFWZ_2_Layer", event_prop, "NO_ZERO")
    arcpy.OverlayRouteEvents_lr(out_gdb + "loc_BAFWZ_2_Layer", event_prop, out_gdb + "loc_E03", event_prop, "UNION", out_gdb + "loc_BAFWZ_detail", event_prop, "NO_ZERO")

    for field in fields:
        with arcpy.da.UpdateCursor(out_gdb + "loc_BAFWZ_detail", field) as rows:
            for row in rows:
                if row[0] == None or row[0] == '':
                    row[0] = 0
                    rows.updateRow(row)
                elif row[0] in code_FW:
                    x = row[0]
                    row[0] = code_FW.get(x) # Umweg via Variable notwendig
                    rows.updateRow(row)
                else:
                    row[0] = 0
                    rows.updateRow(row)

    with arcpy.da.UpdateCursor(out_gdb + "loc_BAFWZ_detail", ["E03"]) as rows:
        for row in rows:
            if row[0] == '':
                row[0] = 0
            rows.updateRow(row)

    Codes = [a.name for a in arcpy.ListFields(out_gdb + "loc_BAFWZ_detail")]
    for attr in Codes:
        if attr not in list_attr_BAFWZ:
            arcpy.DeleteField_management(out_gdb + "loc_BAFWZ_detail", str(attr))

    # optionale Daten angegeben
    if arcpy.Exists(out_gdb + "loc_BAFWZ_opt"):
        arcpy.OverlayRouteEvents_lr(out_gdb + "loc_BAFWZ_detail", event_prop, out_gdb + "loc_BAFWZ_opt", event_prop, "UNION", out_gdb + "loc_BAFWZ_detail_opt", event_prop, "NO_ZERO")

        Codes = [a.name for a in arcpy.ListFields(out_gdb + "loc_BAFWZ_detail_opt")]
        for attr in Codes:
            if attr not in list_attr_BAFWZ:
                arcpy.DeleteField_management(out_gdb + "loc_BAFWZ_detail_opt", str(attr))

    if arcpy.Exists(out_gdb + "loc_BAFWZ_opt"):
        arcpy.AddField_management(out_gdb + "loc_BAFWZ_detail_opt", "temp_BAFWZ", "FLOAT")

        with arcpy.da.UpdateCursor(out_gdb + "loc_BAFWZ_detail_opt", ["E01", "E02", "BAFWZ_opt", "temp_BAFWZ"]) as rows:
            for row in rows:
                a = str(row[0])
                b = str(row[1])
                c = str(row[2])

                if a == '0' and b == '0' and c == '0':
                    row[3] = 0
                elif a == '0.5' or b == '0.5' or c == '0.5':
                    row[3] = 0.5
                elif a == '0,5' or b == '0,5' or c == '0,5':  # bei Verwendung von Komma in regionalen Einstellungen
                    row[3] = 0.5
                elif a == '1' or b == '1' or c == '1':
                    row[3] = 1
                elif a == '2' or b == '2' or c == '2':
                    row[3] = 2
                else:
                    row[3] = 0

                rows.updateRow(row)

        arcpy.DissolveRouteEvents_lr(out_gdb + "loc_BAFWZ_detail_opt", event_prop, ["temp_BAFWZ"], out_gdb + "loc_BAFWZ", event_prop, "CONCATENATE")

    else:
        arcpy.AddField_management(out_gdb + "loc_BAFWZ_detail", "temp_BAFWZ", "FLOAT")

        with arcpy.da.UpdateCursor(out_gdb + "loc_BAFWZ_detail", ["E01", "E02", "temp_BAFWZ"]) as rows:
            for row in rows:
                a = str(row[0])
                b = str(row[1])

                if a == '0' and b == '0':
                    row[2] = 0
                elif a == '0.5' or b == '0.5':
                    row[2] = 0.5
                elif a == '0,5' or b == '0,5':  # bei Verwendung von Komma in regionalen Einstellungen
                    row[2] = 0.5
                elif a == '1' or b == '1':
                    row[2] = 1
                elif a == '2' or b == '2':
                    row[2] = 2
                else:
                    row[2] = 0

                rows.updateRow(row)

        arcpy.DissolveRouteEvents_lr(out_gdb + "loc_BAFWZ_detail", event_prop, ["temp_BAFWZ"], out_gdb + "loc_BAFWZ", event_prop, "CONCATENATE")

    arcpy.DissolveRouteEvents_lr(out_gdb + "loc_BAFWZ_detail", event_prop, ["E03"], out_gdb + "loc_UTFWZ", event_prop, "CONCATENATE")
    arcpy.AlterField_management(out_gdb + "loc_UTFWZ", "E03", "temp_UTFWZ", "temp_UTFWZ")

except:
    errOut(u"\nERREUR: erreur lors du calcul de leffort damnagement et de la topographie de la zone littorale.")
    sys.exit(1)

## *********************************************************************************************************
#  Schritt 1d: Overlay aller Grundlagen, Inputattribute berechnen
try:
    msgOut(u"\nSuperposition des vnements ditinraires...")

    arcpy.OverlayRouteEvents_lr(out_gdb + "REVIT", event_prop, out_gdb + "loc_BAUS", event_prop, "UNION", out_gdb + "loc_OVERLAY_2_Layer", event_prop, "NO_ZERO")
    arcpy.OverlayRouteEvents_lr(out_gdb + "loc_OVERLAY_2_Layer", event_prop, out_gdb + "loc_UTUS", event_prop, "UNION", out_gdb + "loc_OVERLAY_3_Layer", event_prop, "NO_ZERO")
    arcpy.OverlayRouteEvents_lr(out_gdb + "loc_OVERLAY_3_Layer", event_prop, out_gdb + "loc_BAFWZ", event_prop, "UNION", out_gdb + "loc_OVERLAY_4_Layer", event_prop, "NO_ZERO")
    arcpy.OverlayRouteEvents_lr(out_gdb + "loc_OVERLAY_4_Layer", event_prop, out_gdb + "loc_UTFWZ", event_prop, "UNION", out_gdb + "loc_OVERLAY_5_Layer", event_prop, "NO_ZERO")
    arcpy.OverlayRouteEvents_lr(out_gdb + "loc_OVERLAY_5_Layer", event_prop, out_gdb + "loc_OEB", event_prop, "UNION", out_gdb + "REVIT", event_prop, "NO_ZERO")

    with arcpy.da.UpdateCursor(out_gdb + "REVIT", ["BAUS", "temp_BAUS", "UTUS", "temp_UTUS",
                                                   "BAFWZ", "temp_BAFWZ", "UTFWZ", "temp_UTFWZ",
                                                   "OEB", "temp_OEB"]) as rows:
        for row in rows:
            row[0] = row[1]
            row[2] = row[3]
            row[4] = row[5]
            row[6] = row[7]
            row[8] = row[9]
            rows.updateRow(row)
        del row
        del rows

    list_attr = [a.name for a in arcpy.ListFields(out_gdb + "REVIT")]
    for attr in list_attr:
        if attr not in allg_Attribute + Attribute:
            arcpy.DeleteField_management(out_gdb + "REVIT", str(attr))

except:
    errOut(u"\nERREUR: erreur lors de la superposition.")
    sys.exit(1)

## *********************************************************************************************************
#  Schritt 1e: Berechnung Aufwertungspotenzial, theoretischer Nutzen fuer Natur und Landschaft (vor Expertenbereinigung)
try:
    msgOut(u"\nCalcul des attributs...")

    # leere Felder bereinigen
    with arcpy.da.UpdateCursor(out_gdb + "REVIT", ["OEB", "UTFWZ", "UTUS", "APFWZ", "RBFWZ", "BAFWZ", "APUS", "RBUS", "BAUS"]) as rows:
        for row in rows:
            if row[0] == '':
                row[0] = 1
            elif float(row[0]) == 0:
                row[0] = 1
            if row[1] == '':
                row[1] = 1
            elif float(row[1]) == 0:
                row[0] = 1
            if row[2] == '':
                row[2] = 1
            elif float(row[2]) == 0:
                row[0] = 1
            row[3] = float(row[4]) * float(row[5])
            row[6] = float(row[7]) * float(row[8])
            rows.updateRow(row)

    with arcpy.da.UpdateCursor(out_gdb + "REVIT", ["RBUL", "RBUS", "UTUS", "ULWUS", "RBFWZ", "UTFWZ", "ULWFWZ", "RBHL", "HLW"]) as rows:
        for row in rows:
            if float(row[0]) > float(row[1]):
                if float(row[2]) >= 1:
                    row[3] = 2 * ((float(row[0]) - float(row[1]))/2)
                else:
                    row[3] = 0
            else:
                row[3] = 0
            if float(row[0]) > float(row[4]):
                if float(row[5]) >= 1:
                    row[6] = 4 * ((float(row[0]) - float(row[4]))/2)
                else:
                    row[6] = 0
            else:
                row[6] = 0
            if row[7] in (0, 2):
                row[8] = 3
            else:
                row[8] = 0
            rows.updateRow(row)

    with arcpy.da.UpdateCursor(out_gdb + "REVIT", ["APP", "GISNP", "APFWZ", "UTFWZ", "APUS", "UTUS", "ULWUS", "ULWFWZ", "HLW", "OEB"]) as rows:
        for row in rows:
            row[0] = float(row[2]) * float(row[3]) + float(row[4]) * float(row[5]) + float(row[6]) + float(row[7]) + float(row[8])
            row[1] = round((float(row[2]) * float(row[3]) + float(row[4]) * float(row[5]) + float(row[6]) + float(row[7]) + float(row[8])) * float(row[9]), 0)
            rows.updateRow(row)

    with arcpy.da.UpdateCursor(out_gdb + "REVIT", ["AP", "APP"]) as rows:
        for row in rows:
            if row[1] <= 7:
                row[0] = 1
            elif row[1] <= 14:
                row[0] = 2
            else:
                row[0] = 3
            rows.updateRow(row)
        del row
        del rows

    with arcpy.da.UpdateCursor(out_gdb + "REVIT", ["offset_a1", "offset_a2", "offset_i1", "offset_i2"]) as rows:
        for row in rows:
            row[0] = offset_a1
            row[1] = offset_a2
            row[2] = offset_i1
            row[3] = offset_i2
            rows.updateRow(row)
        del row
        del rows

    msgOut(u"\nSuppression des tables temporaires...")
    arcpy.env.workspace = out_gdb
    tables = arcpy.ListTables()
    for table in tables:
        if table[:3] == "loc":
            arcpy.Delete_management(table)

except:
    errOut(u"\nERREUR: erreur lors du calcul des bnfices bas sur le SIG.")
    sys.exit(1)

## *********************************************************************************************************
#  Schritt 1f: Domains und Darstellung
try:
    msgOut(u"\nCration des domaines...")
    desc = arcpy.Describe(out_gdb)
    domains = desc.domains
    for domain in domains:
        arcpy.DeleteDomain_management(out_gdb, domain)
    for domain in list_domain:
        arcpy.CreateDomain_management(out_gdb, domain[0], domain[1], domain[2], domain[3])
        for value in domain[4]:
            arcpy.AddCodedValueToDomain_management(out_gdb, domain[0], value[0], value[1])
        arcpy.SortCodedValueDomain_management(out_gdb, domain[0], "CODE", "ASCENDING")
    msgOut(u"\nAttribution des domaines...")
    for attribute in attribute_domain:
        arcpy.AssignDomainToField_management(out_gdb + str(attribute[0]), attribute[1], attribute[2])

except:
    errOut(u"\nERREUR: erreur lors de la cration des domaines.")
    sys.exit(1)

## *********************************************************************************************************
#  Benutzeranweisung
msgOut("\n" + u"Gnration de la table REVIT. Avant de pouvoir continuer avec ltape 2, les limites de classe pour le bnfice SIG doivent tre dtermines." + "\n")
