# -*- coding: cp1252 -*-
#------------------------------------------------------------------------------
# Name:        02_Benefice_SIG.py
# Version:     1.0
#
# Purpose:     Strategische Revitalisierungsplanung Seeufer: GIS-Analyse
#
# Author:      Sigmaplan AG, Bern
#
# Last Edited: 15.02.2019
#
# Copyright:   (c) BAFU
#
# Python:      2.7.5
# ArcGIS:      10.4.1 (ArcView License)
#------------------------------------------------------------------------------

import os
import arcpy
import datetime

starttime = datetime.datetime.now()

## *********************************************************************************************************
# Benutzereingaben und Umgebung
in_gdb = arcpy.GetParameterAsText(0) + "\\"
untere_Grenze = arcpy.GetParameterAsText(1)
obere_Grenze = arcpy.GetParameterAsText(2)
arcpy.env.workspace = in_gdb
arcpy.env.overwriteOutput = True
event_prop = "ID_Uferlinie LINE Von Bis"

## *********************************************************************************************************
# Weitere Variablen und Listen

list_lyr = ["linRef_REVIT_GISN.lyr", "linRef_REVIT_RB.lyr", "linRef_REVIT_AP.lyr", "linRef_REVIT_OEB.lyr"]

# Pfade
path_script = os.path.dirname(sys.argv[0])
path_in = path_script.replace("\\", r"\\")
path_db = in_gdb
path_out = os.path.dirname(os.path.dirname(path_db))
path_out = path_out.replace("\\", r"\\")

## *********************************************************************************************************
# Funktionen

def msgOut(msg):
    print msg
    arcpy.AddMessage(msg)

def errOut(err):
    print err
    print arcpy.GetMessages()
    print datetime.datetime.now()-starttime
    arcpy.AddError(err)
    arcpy.AddError(arcpy.GetMessages())
    arcpy.AddError(datetime.datetime.now()-starttime)

## *********************************************************************************************************
#  Schritt 2a: GIS-Nutzen klassieren
try:
    msgOut(u"\nClassification du bnfice bas sur le SIG...")
    with arcpy.da.UpdateCursor(in_gdb + "REVIT", ["GISN", "GISNP"]) as rows:
        for row in rows:
            if row[1] <= int(untere_Grenze):
                row[0] = 1
                rows.updateRow(row)
            elif row[1] >= int(obere_Grenze):
                row[0] = 3
                rows.updateRow(row)
            else:
                row[0] = 2
                rows.updateRow(row)

except:
    errOut(u"\nERREUR: erreur lors de la classification du bnfice bas sur le SIG.")
    sys.exit(1)

## *********************************************************************************************************
#  Schritt 2b: lyr-Files kopieren
try:
    msgOut(u"\nCopie des lyr-Files...")
    for lyr in list_lyr:
        arcpy.Copy_management(path_in + "\\lyr_linRef\\" + str(lyr), path_out + "\\"  + str(lyr))

except:
    errOut(u"\nERREUR: erreur lors de la copie des lyr-Files.")
    sys.exit(1)

## *********************************************************************************************************
#  Benutzeranweisung
msgOut("\n" + u"Le bnfice bas sur le SIG a t calcul et saisi dans la table REVIT." + "\n" + u"Pour laffichage de rsultats intermdiaires particuliers (comorphologie, importance cologique et paysagre, potentiel de valorisation, bnfice bas sur le SIG), des fichiers de symbologie sont  disposition." + "\n" + u"Lanalyse peut poursuivre  ltape 3 Agrgation." + "\n")


