# -*- coding: cp1252 -*-
#------------------------------------------------------------------------------
# Name:        03_Agregation.py
# Version:     1.0
#
# Purpose:     Strategische Revitalisierungsplanung Seeufer: GIS-Analyse
#
# Author:      Sigmaplan AG, Bern
#
# Last Edited: 15.02.2019
#
# Copyright:   (c) BAFU
#
# Python:      2.7.5
# ArcGIS:      10.4.1 (ArcView License)
#------------------------------------------------------------------------------

import os
import arcpy
import datetime

starttime = datetime.datetime.now()

## *********************************************************************************************************
# Benutzereingaben und Umgebung
in_gdb = arcpy.GetParameterAsText(0) + "\\"
in_Laenge = arcpy.GetParameterAsText(1)
arcpy.env.workspace = in_gdb
arcpy.env.overwriteOutput = True
event_prop = "ID_Uferlinie LINE Von Bis"

## *********************************************************************************************************
# Weitere Variablen und Listen
list_Massnahmen = ["MASSN1", "MASSN2", "MASSN3", "MASSN4", "MASSN5", "MASSN6", "MASSN7", "MASSN8", "MASSN9", "MASSN0"]
list_lyr = ["linRef_REVIT_AGGR.lyr", "linRef_PLAUS.lyr"]

# Pfade
path_script = os.path.dirname(sys.argv[0])
path_in = path_script.replace("\\", r"\\")
path_db = in_gdb
path_out = os.path.dirname(os.path.dirname(path_db))
path_out = path_out.replace("\\", r"\\")

# Domains
attribute_domain = [
    ("REVIT_AGGR", "GISN_AGGR", "domNutzen"),
    ("PLAUS", "NUTZEN", "domNutzen"),
    ("PRIO", "FRIST", "domFrist"),
    ("PRIO", "MASSN1", "domJaNein"),
    ("PRIO", "MASSN2", "domJaNein"),
    ("PRIO", "MASSN3", "domJaNein"),
    ("PRIO", "MASSN4", "domJaNein"),
    ("PRIO", "MASSN5", "domJaNein"),
    ("PRIO", "MASSN6", "domJaNein"),
    ("PRIO", "MASSN7", "domJaNein"),
    ("PRIO", "MASSN8", "domJaNein"),
    ("PRIO", "MASSN9", "domJaNein"),
    ("PRIO", "MASSN0", "domJaNein")
    ]


## *********************************************************************************************************
# Funktionen

def msgOut(msg):
    print msg
    arcpy.AddMessage(msg)

def errOut(err):
    print err
    print arcpy.GetMessages()
    print datetime.datetime.now()-starttime
    arcpy.AddError(err)
    arcpy.AddError(arcpy.GetMessages())
    arcpy.AddError(datetime.datetime.now()-starttime)

## *********************************************************************************************************
# Schritt 3a
#  1. Dissolve, Mindestlaenge bei kein/geringem Nutzen und bei grossem Nutzen testen -> wenn zu kurz zu mittlerem Nutzen schlagen
#  2. Dissolve, Mindestlaenge bei mittlerem Nutzen testen -> wenn zu kurz zu kein/geringem Nutzen schlagen
#  3. Dissolve, Mindestlaenge bei kein/geringem Nutzen testen -> wenn zu kurz zu grossem Nutzen schlagen (sind Abschnitte aus Iteration 2)
#  4. Dissolve
#  5. Temporaere Dateien loeschen
try:
    msgOut(u"\nAgrgation du bnfice bas sur le SIG...")

    arcpy.DissolveRouteEvents_lr(in_gdb + "REVIT", event_prop, "GISN", in_gdb + "temp_dissolve1", event_prop)
    arcpy.AddField_management(in_gdb + "temp_dissolve1", "GISN_AGGR", "FLOAT")
    #  1. Dissolve, Mindestlaenge bei kein/geringem Nutzen und bei grossem Nutzen testen -> wenn zu kurz zu mittlerem Nutzen schlagen
    with arcpy.da.UpdateCursor(in_gdb + "temp_dissolve1", ["GISN_AGGR", "Von", "Bis", "GISN"]) as rows:
        for row in rows:
            row[0] = row[3]
            rows.updateRow(row)
            Abschnittlaenge = float(row[2]) - float(row[1])
            if Abschnittlaenge < float(in_Laenge):
                print Abschnittlaenge
                if row[0] == 1:
                    row[0] = 2
                    rows.updateRow(row)
                elif row[0] == 3:
                    row[0] = 2
                    rows.updateRow(row)
    #  2. Dissolve, Mindestlaenge bei mittlerem Nutzen testen -> wenn zu kurz zu kein/geringem Nutzen schlagen
    arcpy.DissolveRouteEvents_lr(in_gdb + "temp_dissolve1", event_prop, "GISN_AGGR", in_gdb + "temp_dissolve2", event_prop)
    with arcpy.da.UpdateCursor(in_gdb + "temp_dissolve2", ["GISN_AGGR", "Von", "Bis"]) as rows:
        for row in rows:
            Abschnittlaenge = float(row[2]) - float(row[1])
            if Abschnittlaenge < float(in_Laenge):
                if row[0] == 2:
                    row[0] = 3
                    rows.updateRow(row)
    #  3. Dissolve, Mindestlaenge bei kein/geringem Nutzen testen -> wenn zu kurz zu grossem Nutzen schlagen (sind Abschnitte aus Iteration 2)
    arcpy.DissolveRouteEvents_lr(in_gdb + "temp_dissolve2", event_prop, "GISN_AGGR", in_gdb + "temp_dissolve3", event_prop)
    with arcpy.da.UpdateCursor(in_gdb + "temp_dissolve3", ["GISN_AGGR", "Von", "Bis"]) as rows:
        for row in rows:
            Abschnittlaenge = float(row[2]) - float(row[1])
            if Abschnittlaenge < float(in_Laenge):
                if row[0] == 3:
                    row[0] = 1
                    rows.updateRow(row)

    arcpy.DissolveRouteEvents_lr(in_gdb + "temp_dissolve3", event_prop, "GISN_AGGR", in_gdb + "REVIT_AGGR", event_prop)
    arcpy.AddField_management(in_gdb + "REVIT_AGGR", "AGGR", "FLOAT")
    with arcpy.da.UpdateCursor(in_gdb + "REVIT_AGGR", ["AGGR"]) as rows:
        for row in rows:
            row[0] = float(in_Laenge)
            rows.updateRow(row)

    msgOut(u"\nSuppression des tables temporaires...")
    arcpy.env.workspace = in_gdb
    tables = arcpy.ListTables()
    for table in tables:
        if table[:4] == "temp":
            arcpy.Delete_management(table)

except:
    errOut(u"\nERREUR: erreur lors de lagrgation.")
    sys.exit(1)

## *********************************************************************************************************
# Schritt 3b: Domains, Hilfstabellen fuer naechste Schritte
try:
    msgOut(u"\nCration de tables auxiliaires...")
    if arcpy.Exists(in_gdb + "PLAUS"):
        msgOut("Table daide PLAUS disponible.")
    else:
        arcpy.TableToTable_conversion(in_gdb + "REVIT_AGGR", in_gdb, "PLAUS") # Kopie, damit Event Properties gleich
        arcpy.TruncateTable_management(in_gdb + "PLAUS")
        arcpy.DeleteField_management(in_gdb + "PLAUS", ["GISN_AGGR","AGGR"])
        arcpy.AddField_management(in_gdb + "PLAUS", "NUTZEN", "SHORT")
        arcpy.AddField_management(in_gdb + "PLAUS", "BEGRUEND", "TEXT", "", "", 255)

    if arcpy.Exists(in_gdb + "PRIO"):
        msgOut("Table daide PRIO disponible.")
    else:
        arcpy.TableToTable_conversion(in_gdb + "REVIT_AGGR", in_gdb, "PRIO") # Kopie, damit Event Properties gleich
        arcpy.TruncateTable_management(in_gdb + "PRIO")
        arcpy.DeleteField_management(in_gdb + "PRIO", ["GISN_AGGR","AGGR"])
        arcpy.AddField_management(in_gdb + "PRIO", "FRIST", "SHORT")
        for Massnahme in list_Massnahmen:
            arcpy.AddField_management(in_gdb + "PRIO", Massnahme, "SHORT")
            arcpy.AssignDefaultToField_management(in_gdb + "PRIO", Massnahme, "0")
        arcpy.AlterField_management(in_gdb + "PRIO", "FRIST", new_field_alias = "Dlais")
        arcpy.AlterField_management(in_gdb + "PRIO", "MASSN1", new_field_alias = "Dplacement en retrait/suppression dun amnagement de la rive")
        arcpy.AlterField_management(in_gdb + "PRIO", "MASSN2", new_field_alias = "Amnagement dune berge plane par remblayage")
        arcpy.AlterField_management(in_gdb + "PRIO", "MASSN3", new_field_alias = "Adaptation du terrain ct terre")
        arcpy.AlterField_management(in_gdb + "PRIO", "MASSN4", new_field_alias = "Restauration de la zone littorale")
        arcpy.AlterField_management(in_gdb + "PRIO", "MASSN5", new_field_alias = "Remblayage dlots")
        arcpy.AlterField_management(in_gdb + "PRIO", "MASSN6", new_field_alias = "Structuration de la rive")
        arcpy.AlterField_management(in_gdb + "PRIO", "MASSN7", new_field_alias = "Cration de zones humides/de mares dans la zone riveraine")
        arcpy.AlterField_management(in_gdb + "PRIO", "MASSN8", new_field_alias = "Plantations de roseaux/mesures de protection des roseaux")
        arcpy.AlterField_management(in_gdb + "PRIO", "MASSN9", new_field_alias = "Retrait dinstallations de la zone littorale")
        arcpy.AlterField_management(in_gdb + "PRIO", "MASSN0", new_field_alias = "Autre")
        arcpy.AddField_management(in_gdb + "PRIO", "BEM_MASSN", "TEXT", "", "", 255)

    msgOut(u"\nAttribution des domaines...")
    for attribute in attribute_domain:
        arcpy.AssignDomainToField_management(in_gdb + str(attribute[0]), attribute[1], attribute[2])

except:
    errOut(u"ERREUR: erreur lors de lattribution des domaines.")
    sys.exit(1)

## *********************************************************************************************************
#  Schritt 3c: lyr-Files kopieren
try:
    msgOut(u"\nCopie des lyr-Files...")
    for lyr in list_lyr:
        arcpy.Copy_management(path_in + "\\lyr_linRef\\" + str(lyr), path_out + "\\"  + str(lyr))

except:
    errOut(u"\nERREUR: erreur lors de la copie des lyr-Files..")
    sys.exit(1)

## *********************************************************************************************************
#  Benutzeranweisung
msgOut("\n" + u"La table REVIT_AGGR a t gnre. Elle constitue la base du contrle de vraisemblance conduit par les experts. Les corrections des experts seront saisies dans la table PLAUS. Ltape 4 Contrle de vraisemblance peut tre excute." + "\n")


