# -*- coding: cp1252 -*-
#------------------------------------------------------------------------------
# Name:        04_Controle_de_vraisemblance.py
# Version:     1.0
#
# Purpose:     Strategische Revitalisierungsplanung Seeufer: GIS-Analyse
#
# Author:      Sigmaplan AG, Bern
#
# Last Edited: 15.02.2019
#
# Copyright:   (c) BAFU
#
# Python:      2.7.5
# ArcGIS:      10.4.1 (ArcView License)
#------------------------------------------------------------------------------

import os
import arcpy
import datetime

starttime = datetime.datetime.now()

## *********************************************************************************************************
# Benutzereingaben und Umgebung
in_gdb = arcpy.GetParameterAsText(0) + "\\"
arcpy.env.workspace = in_gdb
arcpy.env.overwriteOutput = True
event_prop = "ID_Uferlinie LINE Von Bis"

## *********************************************************************************************************
# Weitere Variablen und Listen

list_lyr = ["linRef_REVIT_PLAUS.lyr", "linRef_PRIO.lyr"]

# Pfade
path_script = os.path.dirname(sys.argv[0])
path_in = path_script.replace("\\", r"\\")
path_db = in_gdb
path_out = os.path.dirname(os.path.dirname(path_db))
path_out = path_out.replace("\\", r"\\")

# Domains
attribute_domain = [
    ("REVIT_PLAUS", "GISN_AGGR", "domNutzen"),
    ("REVIT_PLAUS", "NUTZEN", "domNutzen")
    ]

## *********************************************************************************************************
# Funktionen

def msgOut(msg):
    print msg
    arcpy.AddMessage(msg)

def errOut(err):
    print err
    print arcpy.GetMessages()
    print datetime.datetime.now()-starttime
    arcpy.AddError(err)
    arcpy.AddError(arcpy.GetMessages())
    arcpy.AddError(datetime.datetime.now()-starttime)


## *********************************************************************************************************
#  Schritt 4a: GIS-Nutzen plausibilisieren
try:
    msgOut(u"\nCration de la table de contrle de vraisemblance...")
    arcpy.OverlayRouteEvents_lr(in_gdb + "REVIT_AGGR", event_prop, in_gdb + "PLAUS", event_prop, "UNION", in_gdb + "REVIT_PLAUS", event_prop, "NO_ZERO")
    arcpy.DeleteField_management(in_gdb + "REVIT_PLAUS", ["AGGR"])

    with arcpy.da.UpdateCursor(in_gdb + "REVIT_PLAUS", ["GISN_AGGR", "NUTZEN", "BEGRUEND"]) as rows:
        for row in rows:
            if row[1] < 1:
                row[1] = row[0]
            elif row[1] == row[0]:
                row[2] = ''
            rows.updateRow(row)
        del row
        del rows

except:
    errOut(u"\nERREUR: erreur lors du contrle de vraisemblance.")
    sys.exit(1)

## *********************************************************************************************************
#  Schritt 4b: Domains
try:
    msgOut(u"\nAttribution des domaines...")
    for attribute in attribute_domain:
        arcpy.AssignDomainToField_management(in_gdb + str(attribute[0]), attribute[1], attribute[2])

except:
    errOut(u"\nERREUR: erreur lors de lattribution des domaines.")
    sys.exit(1)

## *********************************************************************************************************
#  Schritt 4c: lyr-Files kopieren
try:
    msgOut(u"\nCopie des lyr-Files...")
    for lyr in list_lyr:
        arcpy.Copy_management(path_in + "\\lyr_linRef\\" + str(lyr), path_out + "\\"  + str(lyr))

except:
    errOut(u"\nERREUR: erreur lors de la copie des lyr-Files.")
    sys.exit(1)

## *********************************************************************************************************
#  Benutzeranweisung
msgOut("\n" + u"Gnration de la table REVIT_PLAUS. Saisie de la dfinition des priorits dans la table PRIO. Ltape 5 Dfinition des priorits peut ensuite tre excute." + "\n")
