# -*- coding: cp1252 -*-
#------------------------------------------------------------------------------
# Name:        05_Definition_des_priorites.py
# Version:     1.0
#
# Purpose:     Strategische Revitalisierungsplanung Seeufer: GIS-Analyse
#
# Author:      Sigmaplan AG, Bern
#
# Last Edited: 15.02.2019
#
# Copyright:   (c) BAFU
#
# Python:      2.7.5
# ArcGIS:      10.4.1 (ArcView License)
#------------------------------------------------------------------------------

import os
import arcpy
import datetime

starttime = datetime.datetime.now()

## *********************************************************************************************************
# Benutzereingaben und Umgebung
in_gdb = arcpy.GetParameterAsText(0) + "\\"
arcpy.env.workspace = in_gdb
arcpy.env.overwriteOutput = True
event_prop = "ID_Uferlinie LINE Von Bis"

## *********************************************************************************************************
# Weitere Variablen und Listen

list_lyr = ["linRef_REVIT_PRIO.lyr"]

# Pfade
path_script = os.path.dirname(sys.argv[0])
path_in = path_script.replace("\\", r"\\")
path_db = in_gdb
path_out = os.path.dirname(os.path.dirname(path_db))
path_out = path_out.replace("\\", r"\\")

# Domains
attribute_domain = [
    ("REVIT_PRIO", "FRIST", "domFrist"),
    ("REVIT_PRIO", "MASSN1", "domJaNein"),
    ("REVIT_PRIO", "MASSN2", "domJaNein"),
    ("REVIT_PRIO", "MASSN3", "domJaNein"),
    ("REVIT_PRIO", "MASSN4", "domJaNein"),
    ("REVIT_PRIO", "MASSN5", "domJaNein"),
    ("REVIT_PRIO", "MASSN6", "domJaNein"),
    ("REVIT_PRIO", "MASSN7", "domJaNein"),
    ("REVIT_PRIO", "MASSN8", "domJaNein"),
    ("REVIT_PRIO", "MASSN9", "domJaNein"),
    ("REVIT_PRIO", "MASSN0", "domJaNein")
    ]

## *********************************************************************************************************
# Funktionen

def msgOut(msg):
    print msg
    arcpy.AddMessage(msg)

def errOut(err):
    print err
    print arcpy.GetMessages()
    print datetime.datetime.now()-starttime
    arcpy.AddError(err)
    arcpy.AddError(arcpy.GetMessages())
    arcpy.AddError(datetime.datetime.now()-starttime)


## *********************************************************************************************************
#  Schritt 5a: Priorisierung
try:
    msgOut(u"Cration de la table de dfinition des priorits...")

    count = arcpy.management.GetCount(in_gdb + "PRIO")
    if str(count) == "0":
        msgOut("")
        sys.exit(1)

    arcpy.TableToTable_conversion(in_gdb + "PRIO", in_gdb, "REVIT_PRIO")
    arcpy.AddField_management(in_gdb + "REVIT_PRIO", "MASSN_NR", "TEXT", "", "", 100)

    with arcpy.da.UpdateCursor(in_gdb + "REVIT_PRIO", ["MASSN_NR", "MASSN1", "MASSN2", "MASSN3", "MASSN4", "MASSN5", "MASSN6", "MASSN7", "MASSN8", "MASSN9"]) as rows:
        for row in rows:
            row[0] = str(1*int(row[1])) + ", " + str(2*int(row[2])) + ", " + str(3*int(row[3])) + ", " + str(4*int(row[4])) + ", " + str(5*int(row[5])) + ", " + str(6*int(row[6])) + ", " + str(7*int(row[7])) + ", " + str(8*int(row[8])) + ", " + str(9*int(row[9])) + ", "
            rows.updateRow(row)
        del row
        del rows

    with arcpy.da.UpdateCursor(in_gdb + "REVIT_PRIO", ["MASSN_NR"]) as rows:
        for row in rows:
            massnahme = row[0]
            massnahme = massnahme.replace("0, ", "")
            massnahme = massnahme[:-2]
            row[0] = massnahme
            rows.updateRow(row)
        del row
        del rows

    with arcpy.da.UpdateCursor(in_gdb + "REVIT_PRIO", ["MASSN_NR", "MASSN0"]) as rows: # Massn0 muss gesondert behandelt werden
        for row in rows:
            if row[1] == 1:
                row[0] = str(row[0]) + ", 0"
                rows.updateRow(row)
        del row
        del rows

except:
    errOut(u"\nERREUR: erreur lors de la dfinition des priorits.")
    sys.exit(1)

## *********************************************************************************************************
#  Schritt 5b: Domains
try:
    msgOut(u"\nAttribution des domaines...")
    for attribute in attribute_domain:
        arcpy.AssignDomainToField_management(in_gdb + str(attribute[0]), attribute[1], attribute[2])

except:
    errOut(u"\nERREUR: erreur lors de lattribution des domaines.")
    sys.exit(1)

## *********************************************************************************************************
#  Schritt 5c: lyr-Files kopieren
try:
    msgOut(u"\nCopie des lyr-Files...")
    for lyr in list_lyr:
        arcpy.Copy_management(path_in + "\\lyr_linRef\\" + str(lyr), path_out + "\\"  + str(lyr))

except:
    errOut(u"\nERREUR: erreur lors de la copie des lyr-Files.")
    sys.exit(1)

## *********************************************************************************************************
#  Benutzeranweisung
msgOut("\n" + u"Dfinition des priorits saisie dans la table REVIT_PRIO. Les fichiers shp peuvent tre exports  ltape 6." + "\n")
