# -*- coding: cp1252 -*-
#------------------------------------------------------------------------------
# Name:        06_Exportation.py
# Version:     1.1
#
# Purpose:     Strategische Revitalisierungsplanung Seeufer: GIS-Analyse
#
# Author:      Sigmaplan AG, Bern
#
# Last Edited: 06.01.2020
#
# Copyright:   (c) BAFU
#
# Python:      2.7.5
# ArcGIS:      10.4.1 (ArcView License)
#------------------------------------------------------------------------------

import os
import arcpy
import datetime

starttime = datetime.datetime.now()

## *********************************************************************************************************
# Benutzereingaben und Umgebung
in_gdb = arcpy.GetParameterAsText(0) + "\\"
out_folder = arcpy.GetParameterAsText(1) + "\\"
Bearbeiter = arcpy.GetParameterAsText(2)
in_Uferlinie = in_gdb + "Uferlinie"
in_RouteID = "ID_Uferlinie"
arcpy.env.workspace = in_gdb
arcpy.env.overwriteOutput = True
event_prop = "ID_Uferlinie LINE Von Bis"

list_tables_revit = ["REVIT", "REVIT_AGGR", "REVIT_PLAUS", "REVIT_PRIO"]
list_lyr_REVIT = ["shp_REVIT_RB.lyr", "shp_REVIT_AP.lyr", "shp_REVIT_OEB.lyr", "shp_REVIT_AGGR.lyr", "shp_REVIT_PLAUS.lyr", "shp_REVIT_PRIO.lyr"]
list_lyr_MGDM = ["mgdm_OekomorpholgieSeeufer.lyr", "mgdm_Oek_L_Bedeutung.lyr", "mgdm_Nutzen_Aufwand.lyr", "mgdm_Umsetzung.lyr"]
list_subdir = ["REVIT", "MGDM_191_2"]

fields_REVIT = ["OBJECTID", "ID_Uferlinie", "Von", "Bis", "RBUS", "RBFWZ", "RBUL", "RBHL", "RB", "BAUS", "BAFWZ", "UTUS", "UTFWZ", "ULWUS", "ULWFWZ", "HLW","APUS", "APFWZ", "APP", "AP", "OEB", "GISNP", "GISN",
                "GISN_AGGR", "AGGR",
                "NUTZEN", "BEGRUEND",
                "FRIST", "BEM_FRIST", "MASSN1", "MASSN2", "MASSN3", "MASSN4", "MASSN5", "MASSN6", "MASSN7", "MASSN8", "MASSN9", "MASSN0", "BEM_MASSN", "MASSN_NR"
                ]

# Pfade
path_script = os.path.dirname(sys.argv[0])
path_in = path_script.replace("\\", r"\\")

## *********************************************************************************************************
# Funktionen

def msgOut(msg):
    print msg
    arcpy.AddMessage(msg)

def errOut(err):
    print err
    print arcpy.GetMessages()
    print datetime.datetime.now()-starttime
    arcpy.AddError(err)
    arcpy.AddError(arcpy.GetMessages())
    arcpy.AddError(datetime.datetime.now()-starttime)

def CreateDir(dir, subdir):
    """ Erstellt Unterordner, sofern diese noch nicht vorhanden sind """
    if arcpy.Exists(dir + subdir):
        msgOut("")
    else:
        os.makedirs(dir + subdir)
        
def oekmo(nn_oekmo):
    """ Wandelt die stetigen Oekomorphologiewerte in Klassen um.
    """
    try:
        if nn_oekmo >= 0.8:
            if nn_oekmo <= 1:
                nn_oekmo = 'naturnah_natuerlich'
            else:
                nn_oekmo = -1
        elif nn_oekmo >= 0.6:
            nn_oekmo = 'wenig_beeintraechtigt'
        elif nn_oekmo >= 0.4:
            nn_oekmo = 'beeintraechtigt'
        elif nn_oekmo >= 0.2:
            nn_oekmo = 'naturfremd'
        elif nn_oekmo >= 0:
            nn_oekmo = 'kuenstlich'
        else:
            nn_oekmo = 'nicht_bestimmt'
        return nn_oekmo
    except:
        print "\nERROR: Fehler in Berechnung Revitalisierungsbedarf"
        print "Dauer: ", datetime.datetime.now()-starttime

## *********************************************************************************************************
#  Schritt 6a: Export Daten Revitalisierungsplanung
try:
    msgOut(u"\nCrer lemplacement de sauvegarde...")
    for subdir in list_subdir:
        CreateDir(out_folder, subdir)

    for table in list_tables_revit:
        msgOut(u"\nshp-Exportation " + str(table) +".shp")
        arcpy.TableToTable_conversion(in_gdb + table, in_gdb, "temp_" + table)
        list_attr = [a.name for a in arcpy.ListFields(in_gdb + "temp_" + table)]
        for attr in list_attr:
            if attr not in fields_REVIT:
                arcpy.DeleteField_management(in_gdb + "temp_" + table, str(attr))

        arcpy.AddField_management(in_gdb + "temp_" + table, "BEARBEITER", "TEXT", "", "", 255)
        arcpy.AddField_management(in_gdb + "temp_" + table, "EXPORTDATE", "DATE")

        with arcpy.da.UpdateCursor(in_gdb + "temp_" + table, ["BEARBEITER","EXPORTDATE"]) as rows:
            for row in rows:
                row[0] = Bearbeiter
                row[1] = datetime.datetime.now()
                rows.updateRow(row)

        arcpy.MakeRouteEventLayer_lr(in_Uferlinie, in_RouteID, in_gdb + "temp_" + str(table), event_prop, "lyr")
        arcpy.CopyFeatures_management("lyr", out_folder + "REVIT\\" + str(table) + ".shp")

    msgOut(u"\nshp-Exportation OekomorphologieSeeufer.shp")
    arcpy.DissolveRouteEvents_lr(in_gdb + "OEKMO", event_prop, ["NN_Oekomorphologie", "NN_Uferstreifen", "NN_FlachWZ", "NN_Uferlinie", "NN_Hinterlandstr"], in_gdb + "temp_OekomorphologieSeeufer", event_prop)
    arcpy.AddField_management(in_gdb + "temp_OekomorphologieSeeufer", "Methode", "TEXT")
    arcpy.AddField_management(in_gdb + "temp_OekomorphologieSeeufer", "Gesamtbeurteilung_Oekomorphologie", "TEXT")
    with arcpy.da.UpdateCursor(in_gdb + "temp_OekomorphologieSeeufer", ["Methode", "Gesamtbeurteilung_Oekomorphologie", "NN_Oekomorphologie"]) as rows:
        for row in rows:
            row[0] = 'BAFU'
            row[1] = oekmo(row[2])
            rows.updateRow(row)
    arcpy.AlterField_management(in_gdb + "temp_OekomorphologieSeeufer", "NN_Oekomorphologie", "OEM_gesamt")
    arcpy.AlterField_management(in_gdb + "temp_OekomorphologieSeeufer", "NN_Uferstreifen", "OEM_Uferstreifen")
    arcpy.AlterField_management(in_gdb + "temp_OekomorphologieSeeufer", "NN_FlachWZ", "OEM_Flachwasserzone")
    arcpy.AlterField_management(in_gdb + "temp_OekomorphologieSeeufer", "NN_Uferlinie", "OEM_Uferlinie")
    arcpy.AlterField_management(in_gdb + "temp_OekomorphologieSeeufer", "NN_Hinterlandstr", "OEM_Hinterland")
    arcpy.MakeRouteEventLayer_lr(in_Uferlinie, in_RouteID, in_gdb + "temp_OekomorphologieSeeufer", event_prop, "lyr")
    arcpy.CopyFeatures_management("lyr", out_folder + "MGDM_191_2\\OekomorphologieSeeufer.shp")

    msgOut(u"\nshp-Exportation Oek_L_Bedeutung.shp")
    arcpy.DissolveRouteEvents_lr(in_gdb + "REVIT", event_prop, "OEB", in_gdb + "temp_Oek_L_Bedeutung", event_prop)
    arcpy.AlterField_management(in_gdb + "temp_Oek_L_Bedeutung", "OEB", "Oek_LS_Bedeutung")
    arcpy.MakeRouteEventLayer_lr(in_Uferlinie, in_RouteID, in_gdb + "temp_Oek_L_Bedeutung", event_prop, "lyr")
    arcpy.CopyFeatures_management("lyr", out_folder + "MGDM_191_2\\Oek_L_Bedeutung.shp")

    msgOut(u"\nshp-Exportation Nutzen_Aufwand.shp")
    arcpy.DissolveRouteEvents_lr(in_gdb + "REVIT_PLAUS", event_prop, "NUTZEN", in_gdb + "temp_Nutzen_Aufwand", event_prop)
    arcpy.AlterField_management(in_gdb + "temp_Nutzen_Aufwand", "NUTZEN", "Nutzen_NL_Aufwand")
    arcpy.MakeRouteEventLayer_lr(in_Uferlinie, in_RouteID, in_gdb + "temp_Nutzen_Aufwand", event_prop, "lyr")
    arcpy.CopyFeatures_management("lyr", out_folder + "MGDM_191_2\\Nutzen_Aufwand.shp")
    
    msgOut(u"\nshp-Exportation Umsetzung.shp")
    arcpy.DissolveRouteEvents_lr(in_gdb + "REVIT_PRIO", event_prop, "FRIST", in_gdb + "temp_Umsetzung", event_prop)
    arcpy.AlterField_management(in_gdb + "temp_Umsetzung", "FRIST", "Zeitfenster_geplante_Umsetzung")
    arcpy.MakeRouteEventLayer_lr(in_Uferlinie, in_RouteID, in_gdb + "temp_Umsetzung", event_prop, "lyr")
    arcpy.CopyFeatures_management("lyr", out_folder + "MGDM_191_2\\Umsetzung.shp")

    msgOut(u"\nSuppression des tables temporaires...")
    arcpy.env.workspace = in_gdb
    tables = arcpy.ListTables()
    list_temp_tables = ["temp_REVIT", "temp_REVIT_AGGR", "temp_REVIT_PLAUS", "temp_REVIT_PRIO", "temp_OekomorphologieSeeufer", "temp_Oek_L_Bedeutung", "temp_Nutzen_Aufwand", "temp_Umsetzung"]
    for table in tables:
        if table in list_temp_tables:
            arcpy.Delete_management(table)

except:
    errOut(u"\nERREUR: erreur lors de lexportation.")
    sys.exit(1)

## *********************************************************************************************************
#  Schritt 6b: lyr-Files kopieren
try:
    msgOut(u"\nCopie des lyr-Files...")
    for lyr in list_lyr_REVIT:
        arcpy.Copy_management(path_in + "\\lyr_shp\\" + str(lyr), out_folder + "REVIT\\" + str(lyr))
    for lyr in list_lyr_MGDM:
        arcpy.Copy_management(path_in + "\\lyr_shp\\" + str(lyr), out_folder + "MGDM_191_2\\" + str(lyr))

except:
    errOut(u"\nERREUR: erreur lors de la copie des lyr-Files.")
    sys.exit(1)

## *********************************************************************************************************
#  Benutzeranweisung
msgOut("\n" + u"Les fichiers shp ont t exports dans le dossier de destination choisi." + "\n")
